# RedUI Header

Red UI Header is a component which provides a customizable header template for mobile applications, allowing you to easily add actions buttons and a search field.

---

## Installation
You can start using it by following the steps below:
 - Install [red-ui core](http://code.zeedhi.com/redui-components/red-ui).
 - Add on your project bower.json file this dependency
    - Example:

```JSON
    "dependencies": {
        "red-ui-header": "*"
    }
```
 - Run `bower install`
 - Add the path to rui header's JavaScript and css on your GruntFile.json.
    - Example:
    
```JavaScript
    var srcFiles = {
		libsJS: [
            "bower_components/red-ui-header/dist/rui-header.js"
        ],
        libsCSS: [
        	"bower_components/red-ui-header/dist/rui-header.css"
        ]
	};
```
 - Add the path to rui header's css and less at the less routine on your GruntFile.json.
    - Example:
    
```JavaScript
		less: {
			development: {
				files: {
					'bower_components/red-ui-header/dist/rui-header.css': "bower_components/red-ui-header/src/assets/css/**/*.less"
				}
			}
		}
```
 -  Run `grunt less`


---

## Creating your header

To make use of RUI's header you need to set your header property at your main widget with the path to header template.
 - Example:
 
```JSON
 "header": "rui-header#component/header.html",
```

### Header Title
You can set the text to be displayed at the header by setting the `title` property. 

---

### Header Actions
You can add your actions into the header by using the `headerActions` property at the widget, so when that widget gets activated these actions are going to be shown at the header. 

- name: this property defines the name of the header action.
- icon: The icon attribute defines the icon to be displayed by the header, it must be set as a name of a icon found at [material icons](https://material.io/icons/), white spaces are not allowed, so use _ when the icon's name is composite.
- showAsAction: Defines when and where to display the item on the header.
- events: allows the user to trigger an action by clicking the corresponding button on the header.


---
### Header Search

You can allow the user to use the header to filter the rows that match some pattern by using a header search. Header search uses the following properties:
- headerSearchBy: Define the name of the field to search by.
- showSearch: Enable the user to use the header search.

---
## Sample code
```JSON
    {
    	"name": "Sample",
    	"label": "Sample",
    	"template": "container/window.html",
    	"header": "rui-header#component/header.html",
    	"showFooter": false,
    	"showHeader": true,
    	"showMenu": true,
    	"widgets": [
    		{
    			"name": "Product",
    			"label": "Product",
    			"title": "Product",
    			"isVisible": true,
    			"floatingControl": false,
    			"template": "widget/list.html",
    			"headerActions": [
    				{
    					"name": "refresh",
    					"label": "Refresh",
    					"icon": "refresh",
    					"isVisible": true,
    					"showAsAction": "always",
    					"events": [
    						{
    							"name": "ActionEvent",
    							"code": "args.owner.widget.reload();"
    						}
    					]
    				}
    			],
    			"showSearch": true,
    			"headerSearchBy": "CDPRODUTO",
    			"dataSource": {
    				"name": "/product",
    				"rest": true
    			},
    			"fields": [
    				{
    					"name": "CDPRODUTO",
    					"label": "Code",
    					"template": "rui-fields#field/text.html",
    					"showOnForm": true,
    					"showOnList": true,
    					"isVisible": true
    				},
    				{
    					"name": "NMPRODUTO",
    					"label": "Name",
    					"template": "rui-fields#field/text.html",
    					"showOnForm": true,
    					"showOnList": true,
    					"isVisible": true
    				}
    			]
    		}
    	]
    }
```

---
```
Made by:
- Bernardo Santos bernardo.santos@teknisa.com
- Gabriel Andrade gabriel.andrade@teknisa.com
- Gabriel Mello gabriel.mello@teknisa.com
- Luiz Filho luiz.filho@teknisa.com
- Matheus Resende matheus.guedes@teknisa.com
- Samuel Cunha samuel.cunha@teknisa.com
- Rodrigo Rodrigues rodrigo.rodrigues@teknisa.com